==> ccscript3-0.1.2.tar.gz: ccscript3-0.1.2/optional/odbc/methods.cpp <==
// Copyright (C) 1999-2005 Open Source Telecom Corporation.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.
//
// This exception applies only to the code released under the name GNU
// ccScript.  If you copy code from other releases into a copy of GNU
// ccScript, as the General Public License permits, the exception does
// not apply to the code that you add in this way.  To avoid misleading
// anyone as to the status of such modified files, you must delete
// this exception notice from them.
//
// If you write modifications of your own for GNU ccScript, it is your choice
// whether to permit this exception to apply to your modifications.
// If you do not wish that, delete this exception notice.
//

#include "module.h"

using namespace ccscript3Database;
using namespace std;
using namespace ost;

bool SQLMethods::scrSQL(void)
{
	SQLDatabase *current, *prior;
	const char *kw = getKeyoption("results");
	Symbol *sym = NULL;
	const char *name = getSymbol("sql.database");
	char dbname[128];

	if(kw)
	{
		if(*kw == '&')
			sym = mapSymbol(++kw);
		if(!sym)
		{
			error("sql-results-undefined");
			return true;
		}
		clear(sym);
	}

	if(name && *name && stricmp(name, "none"))
	{
		snprintf(dbname, sizeof(dbname), "odbc.%s", name);
		prior = (SQLDatabase *)image->getPointer(dbname);
	}

	snprintf(dbname, sizeof(dbname), "odbc.%s", getName()->filename);
	name = image->getLast(dbname);
	if(name)
		current = (SQLDatabase *)image->getPointer(name);

	if(!current)
	{
		error("sql-no-database-for-script");
		return true;
	}

	new SQLThread(dynamic_cast<ScriptInterp *>(this), current, prior, sym);
	return false;
}

==> ccscript3-0.6.2.tar.gz: ccscript3-0.6.2/optional/odbc/methods.cpp <==
// Copyright (C) 1999-2005 Open Source Telecom Corporation.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.
//
// This exception applies only to the code released under the name GNU
// ccScript.  If you copy code from other releases into a copy of GNU
// ccScript, as the General Public License permits, the exception does
// not apply to the code that you add in this way.  To avoid misleading
// anyone as to the status of such modified files, you must delete
// this exception notice from them.
//
// If you write modifications of your own for GNU ccScript, it is your choice
// whether to permit this exception to apply to your modifications.
// If you do not wish that, delete this exception notice.
//

#include "module.h"

using namespace ccscript3Database;
using namespace std;
using namespace ost;

bool SQLMethods::scrSQL(void)
{
	SQLDatabase *current;
	const char *kw = getKeyoption("results"), *name;
	Symbol *sym = NULL;
	char dbname[128];

	if(kw)
	{
		if(*kw == '&')
			sym = mapSymbol(++kw);
		if(!sym)
		{
			error("sql-results-undefined");
			return true;
		}
		clear(sym);
	}

	snprintf(dbname, sizeof(dbname), "odbc.%s", getName()->filename);
	name = image->getLast(dbname);
	if(name)
		current = (SQLDatabase *)image->getPointer(name);

	if(!current)
	{
		error("sql-no-database-for-script");
		return true;
	}

	new SQLThread(dynamic_cast<ScriptInterp *>(this), current, sym);
	return false;
}
